summaryrefslogtreecommitdiffstats
path: root/kcmshell/main.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcmshell/main.h')
-rw-r--r--kcmshell/main.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kcmshell/main.h b/kcmshell/main.h
index 6a7c34ee7..f43cf98cb 100644
--- a/kcmshell/main.h
+++ b/kcmshell/main.h
@@ -28,9 +28,9 @@
#include <kcmultidialog.h>
/**
* The KApplication instance for kcmshell.
*/
-class KCMShell : public KApplication
+class KCMShell : public TDEApplication
{
Q_OBJECT
@@ -28,9 +28,9 @@
#include <kcmultidialog.h>
/**
- * The KApplication instance for kcmshell.
+ * The TDEApplication instance for kcmshell.
*/